function array = pgmread(filename, type)
%PGMREAD reads a .pgm image file
%
%  Author: David Ross

% check the number of arguments
if nargin < 1 | nargin > 2
    error('incorrect arguments');
end

if nargin == 2
    if not(strcmp(type, 'vector') | strcmp(type, 'array'))
        error('incorrect type specification');
    end
else
    type = 'array';
end

% start reading the file
[file, message] = fopen(filename, 'r');
if file == -1
    message = sprintf('error opening file %s\n%s', filename, message);
    error(message);
end

% read the 'magic number'
line = fgets(file);
magic_number = sscanf(line, '%s');
if strcmp(magic_number, 'P2')
    format = 'text';
elseif strcmp(magic_number, 'P5');
    format = 'binary';
else
    error(sprintf('unknown format %s!', magic_number));
end

% print the comment

% first remember the current position
% - we'll rewind the file to here if we don't find a comment
file_position = ftell(file);
if file_position == -1
    error(ferror(file));
end

% check the next line for a comment
line = fgets(file);
if line(1) == '#'
    % there is a comment, so output it
    %disp(line);
else
    % otherwise there is no comment, so rewind the file and continue
    % from where we were before
    status = fseek(file, file_position, 'bof');
    if status == -1
        error(ferror(file));
    end
end

% read the size
[A, count] = fscanf(file, '%d', [1,3]);
if count ~= 3
    error('trouble reading the size & maximum value');
end
rows = A(1,1);
cols = A(1,2);
maxval = A(1,3);

% drop the white space trailing maxval
fread(file, 1, 'int8');

if maxval <= 255
    number_format = 'uint8';
else     
    number_format = 'uint16';
end 
[array, count] = fread(file, cols*rows, number_format);

%disp(count);
%disp(cols * rows);

if count ~= cols * rows
    error('premature end of image file, number of pixels < cols*rows');
end

%disp(sprintf('read %d pixel values', count));

if strcmp(type, 'array')
    array = (reshape(array,rows,cols))';
else
    error('vector not implemented yet');
end

% finish
fclose(file);
