function plot_b(B)
% plot_b plots the B's produced by MCVQ
%   B is the matrix of priors on the selection of
%   of vectors for each VQ
%
%   Author: David Ross

error(nargchk(1,1,nargin));

if ndims(B) == 2
    
    %-----------------------------------------------
    % Generate the labels for the legend.
    %-----------------------------------------------
    K = size(B,2);
    legend_labels = [];
    for k = 1:K
        legend_labels = [legend_labels; sprintf('VQ %-7d', k)];
    end
    
    %-----------------------------------------------
    % Draw the plot.
    %-----------------------------------------------
    bar(B);
    legend(legend_labels);
    title('Plot of B for each VQ');
    xlabel('index of component within VQ');
    
else
    
    % the number of different classes
    num_classes = size(B,3);
    
    % Determine subplot sizes
    rows = ceil(sqrt(num_classes));
    cols = floor(sqrt(num_classes));
    if rows*cols < num_classes
        cols = cols+1;
    end
    
    %-----------------------------------------------
    % Plot B for each of the classes (3rd dimension).
    %-----------------------------------------------
    for ll = 1:size(B,3)
        subplot(rows,cols,ll);
        imagesc(B(:,:,ll)',[0 1]);
        title(sprintf('Data Class %d',ll));
        xlabel('component');
        ylabel('VQ');
    end
end


%-----------------------------------------------
% Set the figure's properties.
%-----------------------------------------------
set(gcf, 'NumberTitle', 'off', 'MenuBar', 'none', 'Name', 'B'); 
