function plot_g(G, image_size)
% plot_g(G, image_size) plots the G's produced by MCVQ for each VQ
%   image_size gives the dimensions of the images stored in each 
%   column of G.  If image_size is not specified, then it is assumed 
%   the images are square.
%
%   Author: David Ross

%-----------------------------------------------
% Check the input.
%-----------------------------------------------
error(nargchk(1,2,nargin));

N = size(G,1); % number of elements in a data vector
K = size(G,2); % number of VQ's

% if the image size hasn't been specified, the assume it's square
% otherwise read the size from the argument
if nargin == 1
    img_width = sqrt(N);
    img_height = img_width;
else
    img_height = image_size(1);
    img_width = image_size(2);
end


%-----------------------------------------------
% Set the figure's properties.
%-----------------------------------------------
set(gcf, 'NumberTitle', 'off', 'MenuBar', 'none', 'Name', 'G'); 


%-----------------------------------------------
% Draw the plots.
%-----------------------------------------------
plot_index = 1;

for k = 1:K
    subplot(K, 2 , plot_index);
    plot_index = plot_index + 1;
    set(gca, 'Visible', 'off');     
    text(0.5, 0.5, sprintf('VQ %d', k));
    
    my_subplot(K, 2, plot_index);
    plot_index = plot_index + 1;

    %-- use this one so that all pixel intensities are plotted over
    %-- the range [0,1]
    imagesc(reshape(G(:,k), img_height, img_width), [0 1]);
    %disp('plotting pixel intensities on range [0 1]');

    %-- use this one if the difference in pixel values is small, 
    %-- in which case an adaptive scale will better show the differences
    %imagesc(reshape(G(:,k), img_height, img_width), ...
    %    [min(min(G)) max(max(G))]);
    % disp('plotting pixel intensities on range [%g %g]', ...
    %   min(min(G)), max(max(G)));
    %colorbar;
    
    colormap('gray');
    set(gca, 'Visible', 'off');
    axis equal tight;   
end
