function plot_results_new(A, B, G, M, W, Cost, image_size)
%PLOT_RESULTS_NEW plots the model learned by MCVQ
%    plot_results_new(A, B, G, M, W, Cost, image_size)
%       Note that this function will plot only the non-empty
%       matricies it it given.  It will work as long as G
%       is not [].
%
%       image_size should specify the width and the height 
%       of the data images.  If the images are square, then
%       image_size can be omitted.
%
%    Author: David Ross

error(nargchk(6,7,nargin));

N = size(G,1); % number of elements in a data vector
K = size(G,2); % number of VQ's

% if no image size has been specified, assume the image 
% is square
if nargin == 6
    image_size = [sqrt(N) sqrt(N)];
end


% plot A, for each VQ - note that the plot is the same as for  g
if ~isempty(A)
    figure;
    plot_g(A, image_size);
    set(gcf, 'Name', 'A'); 
end

% plot B
if ~isempty(B)
    figure;
    plot_b(B);
end


% plot M
if ~isempty(M)
    figure;
    plot_m(M);
end


% plot G, for each VQ
if ~isempty(G)
    figure;
    plot_g(G, image_size);
end


% plot W
if ~isempty(W)
    figure;
    plot_weights(W, image_size);
    figure;
    plot_weights(W, image_size, G);
%    disp('actually using A to mask Mu');
    disp('actually using mean(G) to mask Mu');
end


% plot the free energies, for each iteration
if ~isempty(Cost)
    figure;
    plot_cost(Cost);
end
